@@ -24,18 +24,21 @@ class QueryManager:
         self.athena = boto3.client('athena', region_name='ap-northeast-2')
         self.s3 = boto3.client('s3', region_name='ap-northeast-2')
 
-    def execute(self, query: str, database: str) -> str:
+    def execute(self, query: str, source: str = "AwsDataCatalog", database: str = None) -> str:
         # Remove trailing semicolon if present
         query = query.strip().rstrip(';')
 
         response = self.athena.start_query_execution(
             QueryString=query,
-            QueryExecutionContext={'Database': database},
+            QueryExecutionContext={
+                'Database': database,
+                'Catalog': source
+            },
             ResultConfiguration={'OutputLocation': self._s3_output}
         )
         return response['QueryExecutionId']
 
-    def wait_for_completion(self, query_id: str, interval: int = 5, timeout: int = 300) -> str:
+    def wait_for_completion(self, query_id: str, interval: int = 5, timeout: int = 1800) -> str:
         start_time = time.time()
         while True:
             response = self.athena.get_query_execution(QueryExecutionId=query_id)
@@ -89,17 +92,17 @@ class QueryManager:
         except Exception as e:
             raise AthenaQueryError(f"Failed to read query result: {str(e)}")
 
-    def query(self, query: str, database: str, auto_cleanup: bool = None, output_format: Literal["polars", "pandas"] = "polars") -> Union[pl.DataFrame, pd.DataFrame]:
-        query_id = self.execute(query, database)
+    def query(self, query: str, source: str = "AwsDataCatalog", database: str = None, auto_cleanup: bool = None, output_format: Literal["polars", "pandas"] = "polars") -> Union[pl.DataFrame, pd.DataFrame]:
+        query_id = self.execute(query, source, database)
         self.wait_for_completion(query_id)
         return self.get_result(query_id, auto_cleanup=auto_cleanup, output_format=output_format)
 
-    def unload(self, query: str = None, database: str = None, unload_location: str = None) -> list[str]:
+    def unload(self, query: str = None, source: str = "AwsDataCatalog", database: str = None, unload_location: str = None) -> list[str]:
         """
         Execute UNLOAD query or list files from an S3 location.
         """
         if query and database:
-            query_id = self.execute(query, database)
+            query_id = self.execute(query, source, database)
             self.wait_for_completion(query_id)
             search_location = unload_location if unload_location else None
         elif unload_location:
@@ -119,9 +122,12 @@ class QueryManager:
         page_iterator = paginator.paginate(Bucket=bucket, Prefix=prefix)
 
         files = []
+        all_objects = []
         for page in page_iterator:
             for obj in page.get('Contents', []):
                 key = obj['Key']
+                all_objects.append(key)
+
                 # Include Parquet files with or without extension
                 # Athena UNLOAD creates files like: prefix/uuid (without extension)
                 # or with extensions: .parquet, .parquet.gz
@@ -130,6 +136,15 @@ class QueryManager:
                     (not key.endswith('/') and '.' not in key.split('/')[-1])):
                     files.append(f's3://{bucket}/{key}')
 
+        # Debug: Print all objects found
+        if all_objects:
+            print(f"[UNLOAD DEBUG] Found {len(all_objects)} objects in S3:")
+            for obj_key in all_objects:
+                print(f"  - {obj_key}")
+            print(f"[UNLOAD DEBUG] Filtered to {len(files)} files")
+        else:
+            print(f"[UNLOAD DEBUG] No objects found at s3://{bucket}/{prefix}")
+
         return files
 
     def delete_query_results_by_prefix(self, s3_prefix_url: str):
